@@ -1,6 +1,7 @@
 /**
  * Python plugin for Orthanc
- * Copyright (C) 2020-2021 Osimis S.A., Belgium
+ * Copyright (C) 2020-2022 Osimis S.A., Belgium
+ * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -41,6 +42,7 @@
 #include "./sdk_OrthancPluginDicomToJsonFormat.impl.h"
 #include "./sdk_OrthancPluginMetricsType.impl.h"
 #include "./sdk_OrthancPluginValueRepresentation.impl.h"
+#include "./sdk_OrthancPluginReceivedInstanceAction.impl.h"
 #include "./sdk_OrthancPluginImageFormat.impl.h"
 #include "./sdk_OrthancPluginChangeType.impl.h"
 
@@ -80,6 +82,7 @@ void RegisterOrthancSdk(PyObject* module)
   RegisterOrthancPluginDicomToJsonFormatEnumeration(module);
   RegisterOrthancPluginMetricsTypeEnumeration(module);
   RegisterOrthancPluginValueRepresentationEnumeration(module);
+  RegisterOrthancPluginReceivedInstanceActionEnumeration(module);
   RegisterOrthancPluginImageFormatEnumeration(module);
   RegisterOrthancPluginChangeTypeEnumeration(module);
 
